---
name: 功能需求
about: 给本项目提出一些功能上的需求
title: ''
labels: ''
assignees: ''

---

**你的需求与某个问题有关？请描述**
简洁清晰地描述问题是什么？

**描述你想要的解决方案**
简洁清晰地描述你想要做什么。

**描述你考虑的替代品（方案）**
简洁清晰地描述你考虑的可替代的解决方案或者功能。

**附加内容**
任何关于功能请求的内容或截屏。
